DownloadTriggerPort

Trait DownloadTriggerPort 

pub trait DownloadTriggerPort: Send + Sync {
    // Required method
    fn queue_download<'life0, 'async_trait>(
        &'life0 self,
        repo_id: String,
        quantization: Option<String>,
    ) -> Pin<Box<dyn Future<Output = Result<String>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Port trait for triggering downloads.

This abstracts the download manager to avoid tight coupling.

Required Methods

fn queue_download<'life0, 'async_trait>( &'life0 self, repo_id: String, quantization: Option<String>, ) -> Pin<Box<dyn Future<Output = Result<String>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Queue a download for a specific model by repo ID and quantization.

Implementors