ModelFilesReaderPort

Trait ModelFilesReaderPort 

pub trait ModelFilesReaderPort: Send + Sync {
    // Required methods
    fn get_by_model_id<'life0, 'async_trait>(
        &'life0 self,
        model_id: i64,
    ) -> Pin<Box<dyn Future<Output = Result<Vec<ModelFile>>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn update_verification_time<'life0, 'async_trait>(
        &'life0 self,
        id: i64,
        verified_at: DateTime<Utc>,
    ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Port trait for accessing model files repository.

This is a minimal trait that wraps the concrete ModelFilesRepository to avoid circular dependencies.

Required Methods

fn get_by_model_id<'life0, 'async_trait>( &'life0 self, model_id: i64, ) -> Pin<Box<dyn Future<Output = Result<Vec<ModelFile>>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Get all model files for a specific model.

fn update_verification_time<'life0, 'async_trait>( &'life0 self, id: i64, verified_at: DateTime<Utc>, ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Update the last verified timestamp for a model file.

Implementors